@@ -24,10 +24,10 @@ class DKConnection():
         headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + self.token}
         url = 'https://%s/v2/order/create/%s/%s/%s' % (self.hostname, kitchen, recipe, variation)
         payload = {'parameters': overrides, "schedule" : "now"}
+        logger.error("%s" % (str(headers)))
         response = requests.put(url, headers=headers, data=json.dumps(payload))
         attempts = 0
         while attempts < retries and response.status_code != 200:
-            logger.error("%s" % (str(headers))
             response = requests.put(url, headers=headers, data=json.dumps(payload))
             time.sleep(60)
             attempts += 1
@@ -36,7 +36,7 @@ class DKConnection():
     def safeCreateOrder(self, kitchen, recipe, variation, overrides={}, wait_time=10, timeout=50000, test_level=""):
         response = self.createOrder(kitchen, recipe, variation, overrides=overrides)
         if response.status_code != 200:
-            logger.error("%s" % (str(self.headers))
+            logger.error("%s" % (str(self.headers)))
             logger.error("Response %d: %s" % (response.status_code, response.text))
             logger.error("Error Starting Order %s %s %s." % (kitchen, recipe, variation))
             raise DKOrderStartException
